@@ -5,7 +5,7 @@ from CoreLocation import *
 class TestCLLocationManager (TestCase):
     @min_os_level('10.6')
     def testMethods(self):
-        self.failUnlessResultIsBOOL(CLLocationManager.locationServicesEnabled)
+        self.assertResultIsBOOL(CLLocationManager.locationServicesEnabled)
 
 
 if __name__ == "__main__":
